MemoryAllocator: An extension class to allocate memory easily with cython.
==========================================================================

This extension class started as part of the Sage software.

Description
-----------

development website: https://github.com/sagemath/memory_allocator

PyPI page: https://pypi.org/project/memory_allocator

License
-------

GPL-3.0

Upstream Contact
----------------

https://github.com/sagemath/memory_allocator

Dependencies
------------

-  Cython
